<?php

namespace Drupal\certificate\Plugin\certificate\CertificateMapper;

use Drupal;
use Drupal\certificate\Plugin\CertificateMapperBase;
use Drupal\Core\Session\AccountInterface;
use Drupal\course\Entity\Course;
use Drupal\course_credit\Entity\CourseCreditType;

/**
 * @CertificateMapper(
 *  id = "course_credit_awarded",
 *  label = @Translation("Awarded course credit"),
 *  description = @Translation("Using this mapping will award a certificate based on the credit type the user claimed after completing a course. You may set up eligibility for credit types on the credit types page."),
 *  required = {"course_credit"}
 * )
 */
class CourseCreditCertificateMapper extends CertificateMapperBase {

  public function getMapKeys() {
    $options = [];
    $credits = CourseCreditType::loadMultiple();
    $credit_types = Drupal::entityTypeManager()->getStorage('course_credit_type')->loadByProperties(['status' => 1]);

    foreach ($credit_types as $key => $type) {
      $options[$key] = $type->label();
    }
    return $options;
  }

  /**
   * Check if the learner is eligible based on awarded credit in the course
   * @param Course $course
   * @param AccountInterface $account
   * @return type
   */
  public function processMapping(\Drupal\Core\Entity\ContentEntityInterface $entity, AccountInterface $account) {
    $options = [];
    if (Drupal::moduleHandler()->moduleExists('course_credit')) {
      // Check for globals
      $options = parent::processMapping($entity, $account);
      $awarded = Drupal::entityTypeManager()->getStorage('course_credit_awarded')->loadByProperties(['cid' => $entity->id(), 'uid' => $account->id()]);

      foreach ($awarded as $key => $credit) {
        $credit_type = $credit->get('type');
        $credit_type = $credit->get('type')->referencedEntities(0);
        $options[] = $credit_type[0]->id;
      }

      return $options;
    }
  }

}
